summary refs log tree commit diff
path: root/group.c
diff options
context:
space:
mode:
Diffstat (limited to 'group.c')
-rw-r--r--group.c15
1 files changed, 6 insertions, 9 deletions
diff --git a/group.c b/group.c
index a75a319..616f30b 100644
--- a/group.c
+++ b/group.c
@@ -195,15 +195,11 @@ group_hidetoggle(int idx)
 	}
 }
 
-#define GROUP_NEXT(gc, fwd) (fwd) ?					\
-	TAILQ_NEXT(gc, entry) : TAILQ_PREV(gc, group_ctx_q, entry)
-
 /*
  * Jump to the next/previous active group.  If none exist, then just
  * stay put.
  */
 void
-group_slide(int fwd)
+group_cycle(int reverse)
 {
 	struct group_ctx *gc, *showgroup = NULL;
 
@@ -211,10 +207,11 @@ group_slide(int fwd)
 
 	gc = Group_active;
 	for (;;) {
-		gc = GROUP_NEXT(gc, fwd);
+		gc = reverse ? TAILQ_PREV(gc, group_ctx_q, entry) :
+		    TAILQ_NEXT(gc, entry);
 		if (gc == NULL)
-			gc = fwd ? TAILQ_FIRST(&Groupq) :
-			    TAILQ_LAST(&Groupq, group_ctx_q);
+			gc = reverse ? TAILQ_LAST(&Groupq, group_ctx_q) :
+			    TAILQ_FIRST(&Groupq);
 		if (gc == Group_active)
 			break;
@@ -195,15 +195,11 @@ group_hidetoggle(int idx)
 /*
- * Jump to the next/previous active group.  If none exist, then just
- * stay put.
+ * Cycle through active groups.  If none exist, then just stay put.
  */
 void